==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/VirtualHardDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the uri of a disk.
 * @property uri Specifies the virtual hard disk's uri.
 */
public data class VirtualHardDiskArgs(
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs.builder()
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHardDiskArgs].
 */
@PulumiTagMarker
public class VirtualHardDiskArgsBuilder internal constructor() {
    private var uri: Output<String>? = null

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("vropqiulrcxksnxk")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("twklovxycoimmpyu")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): VirtualHardDiskArgs = VirtualHardDiskArgs(
        uri = uri,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/VirtualHardDiskArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes the uri of a disk.
 * @property uri Specifies the virtual hard disk's uri.
 */
public data class VirtualHardDiskArgs(
    public val uri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs> {
    override fun toJava(): com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.VirtualHardDiskArgs.builder()
            .uri(uri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHardDiskArgs].
 */
@PulumiTagMarker
public class VirtualHardDiskArgsBuilder internal constructor() {
    private var uri: Output<String>? = null

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("kwejjexaerngxpia")
    public suspend fun uri(`value`: Output<String>) {
        this.uri = value
    }

    /**
     * @param value Specifies the virtual hard disk's uri.
     */
    @JvmName("noncrbohafanhfha")
    public suspend fun uri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uri = mapped
    }

    internal fun build(): VirtualHardDiskArgs = VirtualHardDiskArgs(
        uri = uri,
    )
}
